angular_displacement

Function angular_displacement 

pub fn angular_displacement(
    initial_angular_velocity: f64,
    angular_acceleration: f64,
    time: f64,
) -> Option<f64>
Computes angular displacement using θ = ω_initial * t + 0.5 * α * t².

Returns None when time is negative, when any input is not finite, or when the computed angular displacement is not finite.