pub const fn statistics(kind: ParticleKind) -> ParticleStatisticsExpand description
Returns the particle statistics implied by the modeled spin.
pub const fn statistics(kind: ParticleKind) -> ParticleStatisticsReturns the particle statistics implied by the modeled spin.