EllipticalOrbit

Struct EllipticalOrbit 

pub struct EllipticalOrbit {
    pub mu: f64,
    pub periapsis_radius: f64,
    pub apoapsis_radius: f64,
}
Elliptical orbit state described by a gravitational parameter and apsides.

Fields

mu: f64

Central-body gravitational parameter in cubic meters per second squared.

periapsis_radius: f64

Periapsis radius in meters.

apoapsis_radius: f64

Apoapsis radius in meters.

Implementations

Source

impl EllipticalOrbit

pub fn new( mu: f64, periapsis_radius: f64, apoapsis_radius: f64, ) -> Option<EllipticalOrbit>

Creates an elliptical orbit from a gravitational parameter and apsides.

Returns None when mu is less than or equal to zero or not finite, or when the apsides are invalid.

pub fn semi_major_axis(&self) -> Option<f64>

Computes the semi-major axis.

pub fn eccentricity(&self) -> Option<f64>

Computes eccentricity.

pub fn period(&self) -> Option<f64>

Computes the orbital period.

Examples
use use_orbit::EllipticalOrbit;

let orbit = EllipticalOrbit::new(100.0, 10.0, 20.0);

assert!(orbit.and_then(|value| value.period()).is_some_and(|period| period > 0.0));
pub fn periapsis_speed(&self) -> Option<f64>

Computes speed at periapsis.

pub fn apoapsis_speed(&self) -> Option<f64>

Computes speed at apoapsis.