MagneticField

Struct MagneticField 

pub struct MagneticField {
    pub flux_density: f64,
}
A simple magnetic field described by flux density.

Fields

flux_density: f64

Implementations

Source

impl MagneticField

pub fn new(flux_density: f64) -> Option<MagneticField>

Creates a new magnetic field from flux density.

pub fn flux_through_area(&self, area: f64, angle_radians: f64) -> Option<f64>

Computes the magnetic flux through an area in this field.

pub fn force_on_charge( &self, charge: f64, velocity: f64, angle_radians: f64, ) -> Option<f64>

Computes the magnetic force on a moving charge in this field.

Examples
use std::f64::consts::FRAC_PI_2;

use use_magnetism::MagneticField;

let field = MagneticField::new(3.0).unwrap();
assert_eq!(field.force_on_charge(1.0, 2.0, FRAC_PI_2), Some(6.0));
pub fn force_on_wire( &self, current: f64, length: f64, angle_radians: f64, ) -> Option<f64>

Computes the magnetic force on a current-carrying wire in this field.

pub fn energy_density(&self) -> Option<f64>

Computes the magnetic energy density for this field.