Spin

Struct Spin 

pub struct Spin {
    pub doubled: i8,
}
A spin value expressed as doubled units of hbar.

Fields

doubled: i8

Spin measured in doubled units of hbar.

Implementations

Source

impl Spin

pub const fn new_doubled(doubled: i8) -> Spin

Creates a spin from doubled units of hbar.

pub const fn zero() -> Spin

Returns spin 0.

pub const fn half() -> Spin

Returns spin 1/2.

pub const fn one() -> Spin

Returns spin 1.

pub fn as_units_of_hbar(self) -> f64

Returns the spin in units of hbar.

pub const fn is_integer(self) -> bool

Returns true when the spin is an integer multiple of hbar.

pub const fn is_half_integer(self) -> bool

Returns true when the spin is a half-integer multiple of hbar.