Module work

Module work 

Modules

prelude

Structs

ConstantForceWork
Constant-force work inputs for repeated calculations.

Functions

displacement_from_work
Computes the displacement implied by a work value and a constant force.
final_kinetic_energy_from_work
Computes final kinetic energy from an initial kinetic energy and applied work.
force_from_work
Computes the force required to perform a given amount of work over a displacement.
initial_kinetic_energy_from_work
Computes initial kinetic energy from a final kinetic energy and applied work.
net_work
Computes the net work from a slice of work contributions.
spring_potential_energy
Computes the spring potential energy stored at a displacement.
spring_work
Computes work done by an ideal spring force over a displacement interval.
work
Computes mechanical work from a constant force and displacement.
work_against_gravity
Computes work done against gravity near a surface.
work_at_angle
Computes mechanical work when the force is applied at an angle to the displacement.
work_at_angle_degrees
Computes mechanical work when the applied-force angle is given in degrees.
work_by_friction
Computes work done by kinetic friction.
work_by_gravity
Computes work done by gravity near a surface.
work_from_force_samples
Approximates work from aligned force and displacement samples.
work_from_kinetic_energy_change
Computes net work from the change in kinetic energy.