pub fn angular_velocity(angular_displacement: f64, time: f64) -> Option<f64>Expand description
Computes angular velocity using ω = Δθ / t.
Returns None when time is less than or equal to zero, when any input is not finite, or
when the computed angular velocity is not finite.
Examples
use use_rotation::angular_velocity;
assert_eq!(angular_velocity(10.0, 2.0), Some(5.0));