pub fn hohmann_transfer_time(
mu: f64,
radius_initial: f64,
radius_final: f64,
) -> Option<f64>Expand description
Computes the transfer time for a Hohmann transfer.
Formula: t_transfer = π * sqrt(a_transfer³ / μ)
Returns None when mu is less than or equal to zero, when either radius is less than or
equal to zero, or when the input or result is not finite.