pub fn shear_stress_from_modulus(
shear_modulus: f64,
shear_strain: f64,
) -> Option<f64>Expand description
Computes shear stress from shear modulus and shear strain.
Formula: τ = Gγ.
Returns None when shear_modulus is negative or when any input or result is not finite.