pub struct EllipticalOrbit {
pub mu: f64,
pub periapsis_radius: f64,
pub apoapsis_radius: f64,
}Expand description
Elliptical orbit state described by a gravitational parameter and apsides.
Fields
mu: f64Central-body gravitational parameter in cubic meters per second squared.
periapsis_radius: f64Periapsis radius in meters.
apoapsis_radius: f64Apoapsis radius in meters.
Implementations
Sourceimpl EllipticalOrbit
impl EllipticalOrbit
Sourcepub fn new(
mu: f64,
periapsis_radius: f64,
apoapsis_radius: f64,
) -> Option<EllipticalOrbit>
pub fn new( mu: f64, periapsis_radius: f64, apoapsis_radius: f64, ) -> Option<EllipticalOrbit>
Creates an elliptical orbit from a gravitational parameter and apsides.
Returns None when mu is less than or equal to zero or not finite, or when the apsides
are invalid.
Sourcepub fn semi_major_axis(&self) -> Option<f64>
pub fn semi_major_axis(&self) -> Option<f64>
Computes the semi-major axis.
Sourcepub fn eccentricity(&self) -> Option<f64>
pub fn eccentricity(&self) -> Option<f64>
Computes eccentricity.
Sourcepub fn period(&self) -> Option<f64>
pub fn period(&self) -> Option<f64>
Computes the orbital period.
Examples
use use_orbit::EllipticalOrbit;
let orbit = EllipticalOrbit::new(100.0, 10.0, 20.0);
assert!(orbit.and_then(|value| value.period()).is_some_and(|period| period > 0.0));Sourcepub fn periapsis_speed(&self) -> Option<f64>
pub fn periapsis_speed(&self) -> Option<f64>
Computes speed at periapsis.
Sourcepub fn apoapsis_speed(&self) -> Option<f64>
pub fn apoapsis_speed(&self) -> Option<f64>
Computes speed at apoapsis.