ElementaryCharge

Struct ElementaryCharge 

pub struct ElementaryCharge {
    pub thirds: i8,
}
An exact electric charge expressed in thirds of the elementary charge.

Fields

thirds: i8

Charge measured in thirds of the elementary charge.

Implementations

Source

impl ElementaryCharge

pub const fn new_thirds(thirds: i8) -> ElementaryCharge

Creates a charge from thirds of the elementary charge.

pub const fn neutral() -> ElementaryCharge

Returns a neutral charge.

pub const fn positive_one() -> ElementaryCharge

Returns a +1e charge.

pub const fn negative_one() -> ElementaryCharge

Returns a -1e charge.

pub fn as_elementary_units(self) -> f64

Returns the charge in elementary-charge units.

Examples found in repository?
examples/facade_particle.rs (line 17)
7fn main() {
8    let electron = Particle::new(ParticleKind::Electron);
9
10    assert_eq!(electron.family(), ParticleFamily::Lepton);
11    assert_eq!(charge(ParticleKind::Electron).thirds, -3);
12    assert_eq!(spin(ParticleKind::Photon).doubled, 2);
13    assert_eq!(
14        antiparticle(ParticleKind::Electron),
15        Some(ParticleKind::Positron)
16    );
17    assert!(approx_eq(electron.charge().as_elementary_units(), -1.0,));
18}
pub const fn is_neutral(self) -> bool

Returns true when the charge is neutral.

pub const fn is_positive(self) -> bool

Returns true when the charge is positive.

pub const fn is_negative(self) -> bool

Returns true when the charge is negative.