pub struct Spin {
pub doubled: i8,
}Expand description
A spin value expressed as doubled units of hbar.
Fields
doubled: i8Spin measured in doubled units of hbar.
Implementations
Sourceimpl Spin
impl Spin
Sourcepub const fn new_doubled(doubled: i8) -> Spin
pub const fn new_doubled(doubled: i8) -> Spin
Creates a spin from doubled units of hbar.
Sourcepub fn as_units_of_hbar(self) -> f64
pub fn as_units_of_hbar(self) -> f64
Returns the spin in units of hbar.
Sourcepub const fn is_integer(self) -> bool
pub const fn is_integer(self) -> bool
Returns true when the spin is an integer multiple of hbar.
Sourcepub const fn is_half_integer(self) -> bool
pub const fn is_half_integer(self) -> bool
Returns true when the spin is a half-integer multiple of hbar.