Modules
Structs
- Constant
Force Work - Constant-force work inputs for repeated calculations.
Functions
- displacement_
from_ work - Computes the displacement implied by a work value and a constant force.
- final_
kinetic_ energy_ from_ work - Computes final kinetic energy from an initial kinetic energy and applied work.
- force_
from_ work - Computes the force required to perform a given amount of work over a displacement.
- initial_
kinetic_ energy_ from_ work - Computes initial kinetic energy from a final kinetic energy and applied work.
- net_
work - Computes the net work from a slice of work contributions.
- spring_
potential_ energy - Computes the spring potential energy stored at a displacement.
- spring_
work - Computes work done by an ideal spring force over a displacement interval.
- work
- Computes mechanical work from a constant force and displacement.
- work_
against_ gravity - Computes work done against gravity near a surface.
- work_
at_ angle - Computes mechanical work when the force is applied at an angle to the displacement.
- work_
at_ angle_ degrees - Computes mechanical work when the applied-force angle is given in degrees.
- work_
by_ friction - Computes work done by kinetic friction.
- work_
by_ gravity - Computes work done by gravity near a surface.
- work_
from_ force_ samples - Approximates work from aligned force and displacement samples.
- work_
from_ kinetic_ energy_ change - Computes net work from the change in kinetic energy.